========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/zun.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. image:: https://www.openstack.org/themes/openstack/images/project-mascots/Zun/OpenStack_Project_Zun_mascot.jpg

.. Change things from this point on

===
Zun
===

OpenStack Containers service

Zun (ex. Higgins) is the OpenStack Containers service. It aims to provide an
API service for running application containers without the need to manage
servers or clusters.

* Free software: Apache license
* Get Started: https://docs.openstack.org/zun/latest/contributor/quickstart.html
* Documentation: https://docs.openstack.org/zun/latest/
* Source: https://opendev.org/openstack/zun
* Bugs: https://bugs.launchpad.net/zun
* Blueprints: https://blueprints.launchpad.net/zun
* REST Client: https://opendev.org/openstack/python-zunclient

Features
--------

* TODO
